A renderer-agnostic native GUI runtime.

iced_runtime takes iced_core and builds a native runtime on top of it.
Re-exports
pub use task::Task;pub use user_interface::UserInterface;pub use ferrishot_iced_core as core;pub use ferrishot_iced_debug as debug;pub use ferrishot_iced_futures as futures;
Modules
- clipboard
- Access the clipboard.
- font
- Load and use fonts.
- keyboard
- Track keyboard events.
- overlay
- Overlays for user interfaces.
- system
- Access the native system.
- task
- Create runtime tasks.
- user_
interface - Implement your own event loop to drive a user interface.
- window
- Build window-based GUI applications.
Enums
- Action
- An action that the iced runtime can perform.